@@ -29,3 +29,13 @@ class DockerClient(object):
 
     def inspect_image(self, name):
         return self.client.images.get(name).attrs
+
+    def is_rootless(self):
+        # TODO
+        return False
+
+    def list_all_containers(self):
+        return [
+            container.name
+            for container in self.client.containers.list(all=True)
+        ]
