@@ -24,7 +24,8 @@ class PodmanClient(object):
             ['podman', 'image', 'inspect', '--format', '{{json .}}', name],
             capture_output=True
         )
-        return json.loads(str(result.stdout, 'utf8').strip())
+        images = json.loads(str(result.stdout, 'utf8').strip())
+        return images[0]
 
     def remove_volume(self, name):
         result = subprocess.run(
@@ -36,3 +37,17 @@ class PodmanClient(object):
             ['podman', 'image', 'inspect', name],
             capture_output=True)
         return result.returncode == 0
+
+    def is_rootless(self):
+        result = subprocess.run(
+            ['podman', 'info', '-f', '{{json .}}'],
+            capture_output=True)
+        info = json.loads(str(result.stdout, 'utf8').strip())
+
+        return info['host']['rootless']
+
+    def list_all_containers(self):
+        result = subprocess.run(
+            ['podman', 'ps', '-a', '--format', '{{.Names}}'],
+            capture_output=True)
+        return str(result.stdout, 'utf-8').strip().split('\n')
